.. demes documentation master file, created by
   sphinx-quickstart on Sun Jul 19 16:51:55 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to demes' documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   installation
   tutorial
   gallery
   api
   convert
   schema
   development
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
